==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/timezones/ur_IN.php <==
<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گرین وچ مین ٹائم (عابدجان)',
        'Africa/Accra' => 'گرین وچ مین ٹائم (اکرا)',
        'Africa/Algiers' => 'وسطی یورپ کا وقت (الجیئرس)',
        'Africa/Bamako' => 'گرین وچ مین ٹائم (بماکو)',
        'Africa/Banjul' => 'گرین وچ مین ٹائم (بنجول)',
        'Africa/Bissau' => 'گرین وچ مین ٹائم (بِساؤ)',
        'Africa/Ceuta' => 'وسطی یورپ کا وقت (سیوٹا)',
        'Africa/Conakry' => 'گرین وچ مین ٹائم (کونکری)',
        'Africa/Dakar' => 'گرین وچ مین ٹائم (ڈکار)',
        'Africa/Freetown' => 'گرین وچ مین ٹائم (فری ٹاؤن)',
        'Africa/Lome' => 'گرین وچ مین ٹائم (لوم)',
        'Africa/Monrovia' => 'گرین وچ مین ٹائم (مونروویا)',
        'Africa/Nouakchott' => 'گرین وچ مین ٹائم (نواکشوط)',
        'Africa/Ouagadougou' => 'گرین وچ مین ٹائم (اؤگاڈؤگوو)',
        'Africa/Sao_Tome' => 'گرین وچ مین ٹائم (ساؤ ٹوم)',
        'Africa/Tunis' => 'وسطی یورپ کا وقت (تیونس)',
        'America/Asuncion' => 'پیراگوئے ٹائم (اسنسیئن)',
        'America/Boa_Vista' => 'ایمیزون ٹائم (بوآ وسٹا)',
        'America/Cambridge_Bay' => 'ماؤنٹین ٹائم (کیمبرج بے)',
        'America/Campo_Grande' => 'ایمیزون ٹائم (کیمپو گرینڈ)',
        'America/Caracas' => 'وینزوئیلا ٹائم (کراکاس)',
        'America/Cayenne' => 'فرینچ گیانا ٹائم (کائین)',
        'America/Cuiaba' => 'ایمیزون ٹائم (کوئیابا)',
        'America/Danmarkshavn' => 'گرین وچ مین ٹائم (ڈنمارک شاون)',
        'America/Glace_Bay' => 'اٹلانٹک ٹائم (گلیس بے)',
        'America/Goose_Bay' => 'اٹلانٹک ٹائم (گوس بے)',
        'America/Grand_Turk' => 'ایسٹرن ٹائم (گرینڈ ترک)',
        'America/Guayaquil' => 'ایکواڈور ٹائم (گوآیاکوئل)',
        'America/Guyana' => 'گیانا ٹائم',
        'America/La_Paz' => 'بولیویا ٹائم (لا پاز)',
        'America/Lima' => 'پیرو ٹائم (لیما)',
        'America/Manaus' => 'ایمیزون ٹائم (مناؤس)',
        'America/Montevideo' => 'یوروگوئے ٹائم (مونٹی ویڈیو)',
        'America/Noronha' => 'فرنانڈو ڈی نورنہا ٹائم (نورونہا)',
        'America/Paramaribo' => 'سورینام ٹائم (پراماریبو)',
        'America/Porto_Velho' => 'ایمیزون ٹائم (پورٹو ویلہو)',
        'America/Punta_Arenas' => 'چلی ٹائم (پنٹا اریناس)',
        'America/Santiago' => 'چلی ٹائم (سنٹیاگو)',
        'America/Scoresbysund' => 'مشرقی گرین لینڈ ٹائم (اتتوققورتورمیت)',
        'America/Thule' => 'اٹلانٹک ٹائم (تھولے)',
        'Antarctica/McMurdo' => 'نیوزی لینڈ ٹائم (میک مرڈو)',
        'Antarctica/Palmer' => 'چلی ٹائم (پلمیر)',
        'Antarctica/Rothera' => 'روتھیرا ٹائم',
        'Antarctica/Troll' => 'گرین وچ مین ٹائم (ٹرول)',
        'Antarctica/Vostok' => 'ووسٹاک ٹائم (ووستوک)',
        'Arctic/Longyearbyen' => 'وسطی یورپ کا وقت (لانگ ایئر بین)',
        'Asia/Aden' => 'عرب ٹائم (عدن)',
        'Asia/Almaty' => 'مشرقی قزاخستان ٹائم (الماٹی)',
        'Asia/Aqtau' => 'مغربی قزاخستان ٹائم (اکتاؤ)',
        'Asia/Aqtobe' => 'مغربی قزاخستان ٹائم (اکٹوب)',
        'Asia/Ashgabat' => 'ترکمانستان ٹائم (اشغبت)',
        'Asia/Atyrau' => 'مغربی قزاخستان ٹائم (آتیراؤ)',
        'Asia/Baghdad' => 'عرب ٹائم (بغداد)',
        'Asia/Bahrain' => 'عرب ٹائم (بحرین)',
        'Asia/Baku' => 'آذربائیجان ٹائم (باکو)',
        'Asia/Bishkek' => 'کرغستان ٹائم (بشکیک)',
        'Asia/Calcutta' => 'انڈیا سٹینڈرڈ ٹائم (کولکاتا)',
        'Asia/Colombo' => 'انڈیا سٹینڈرڈ ٹائم (کولمبو)',
        'Asia/Dhaka' => 'بنگلہ دیش ٹائم (ڈھاکہ)',
        'Asia/Dubai' => 'خلیج سٹینڈرڈ ٹائم (دبئی)',
        'Asia/Dushanbe' => 'تاجکستان ٹائم (دوشانبے)',
        'Asia/Jerusalem' => 'اسرائیل ٹائم (یروشلم)',
        'Asia/Kabul' => 'افغانستان ٹائم (کابل)',
        'Asia/Karachi' => 'پاکستان ٹائم (کراچی)',
        'Asia/Katmandu' => 'نیپال ٹائم (کاٹھمنڈو)',
        'Asia/Kuwait' => 'عرب ٹائم (کویت)',
        'Asia/Muscat' => 'خلیج سٹینڈرڈ ٹائم (مسقط)',
        'Asia/Oral' => 'مغربی قزاخستان ٹائم (اورال)',
        'Asia/Qatar' => 'عرب ٹائم (قطر)',
        'Asia/Qostanay' => 'مشرقی قزاخستان ٹائم (کوستانے)',
        'Asia/Qyzylorda' => 'مغربی قزاخستان ٹائم (کیزیلورڈا)',
        'Asia/Riyadh' => 'عرب ٹائم (ریاض)',
        'Asia/Samarkand' => 'ازبکستان ٹائم (سمرقند)',
        'Asia/Tashkent' => 'ازبکستان ٹائم (تاشقند)',
        'Asia/Tbilisi' => 'جارجیا ٹائم (طبلیسی)',
        'Asia/Tehran' => 'ایران ٹائم (تہران)',
        'Asia/Thimphu' => 'بھوٹان ٹائم (تھمپو)',
        'Asia/Yerevan' => 'آرمینیا ٹائم (یریوان)',
        'Atlantic/Reykjavik' => 'گرین وچ مین ٹائم (ریکجاوک)',
        'Atlantic/St_Helena' => 'گرین وچ مین ٹائم (سینٹ ہیلینا)',
        'Atlantic/Stanley' => 'فاک لینڈ آئلینڈز ٹائم (اسٹینلے)',
        'Etc/GMT' => 'گرین وچ مین ٹائم',
        'Europe/Amsterdam' => 'وسطی یورپ کا وقت (ایمسٹرڈم)',
        'Europe/Andorra' => 'وسطی یورپ کا وقت (انڈورا)',
        'Europe/Belgrade' => 'وسطی یورپ کا وقت (بلغراد)',
        'Europe/Berlin' => 'وسطی یورپ کا وقت (برلن)',
        'Europe/Bratislava' => 'وسطی یورپ کا وقت (بریٹِسلاوا)',
        'Europe/Brussels' => 'وسطی یورپ کا وقت (برسلز)',
        'Europe/Budapest' => 'وسطی یورپ کا وقت (بوڈاپیسٹ)',
        'Europe/Busingen' => 'وسطی یورپ کا وقت (بزنجن)',
        'Europe/Copenhagen' => 'وسطی یورپ کا وقت (کوپن ہیگن)',
        'Europe/Dublin' => 'گرین وچ مین ٹائم (ڈبلن)',
        'Europe/Gibraltar' => 'وسطی یورپ کا وقت (جبل الطارق)',
        'Europe/Guernsey' => 'گرین وچ مین ٹائم (گرنزی)',
        'Europe/Isle_of_Man' => 'گرین وچ مین ٹائم (آئل آف مین)',
        'Europe/Jersey' => 'گرین وچ مین ٹائم (جرسی)',
        'Europe/Ljubljana' => 'وسطی یورپ کا وقت (لیوبلیانا)',
        'Europe/London' => 'گرین وچ مین ٹائم (لندن)',
        'Europe/Luxembourg' => 'وسطی یورپ کا وقت (لگژمبرگ)',
        'Europe/Madrid' => 'وسطی یورپ کا وقت (میڈرڈ)',
        'Europe/Malta' => 'وسطی یورپ کا وقت (مالٹا)',
        'Europe/Monaco' => 'وسطی یورپ کا وقت (موناکو)',
        'Europe/Oslo' => 'وسطی یورپ کا وقت (اوسلو)',
        'Europe/Paris' => 'وسطی یورپ کا وقت (پیرس)',
        'Europe/Podgorica' => 'وسطی یورپ کا وقت (پوڈگورسیا)',
        'Europe/Prague' => 'وسطی یورپ کا وقت (پراگ)',
        'Europe/Rome' => 'وسطی یورپ کا وقت (روم)',
        'Europe/San_Marino' => 'وسطی یورپ کا وقت (سان ماریانو)',
        'Europe/Sarajevo' => 'وسطی یورپ کا وقت (سراجیوو)',
        'Europe/Skopje' => 'وسطی یورپ کا وقت (اسکوپجے)',
        'Europe/Stockholm' => 'وسطی یورپ کا وقت (اسٹاک ہوم)',
        'Europe/Tirane' => 'وسطی یورپ کا وقت (ٹیرانی)',
        'Europe/Vaduz' => 'وسطی یورپ کا وقت (ویڈوز)',
        'Europe/Vatican' => 'وسطی یورپ کا وقت (واٹیکن)',
        'Europe/Vienna' => 'وسطی یورپ کا وقت (ویانا)',
        'Europe/Warsaw' => 'وسطی یورپ کا وقت (وارسا)',
        'Europe/Zagreb' => 'وسطی یورپ کا وقت (زیگریب)',
        'Europe/Zurich' => 'وسطی یورپ کا وقت (زیورخ)',
        'Indian/Maldives' => 'مالدیپ ٹائم',
        'Pacific/Auckland' => 'نیوزی لینڈ ٹائم (آکلینڈ)',
        'Pacific/Easter' => 'ایسٹر آئلینڈ ٹائم',
        'Pacific/Galapagos' => 'گالاپاگوز ٹائم (گیلاپیگوس)',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT%s',
    ],
];

==> symfony_6.4.25+dfsg.orig.tar.xz: symfony-6.4.25/src/Symfony/Component/Intl/Resources/data/timezones/ur_IN.php <==
<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گرین وچ مین ٹائم (عابدجان)',
        'Africa/Accra' => 'گرین وچ مین ٹائم (اکرا)',
        'Africa/Algiers' => 'وسطی یورپ کا وقت (الجیئرس)',
        'Africa/Bamako' => 'گرین وچ مین ٹائم (بماکو)',
        'Africa/Banjul' => 'گرین وچ مین ٹائم (بنجول)',
        'Africa/Bissau' => 'گرین وچ مین ٹائم (بِساؤ)',
        'Africa/Ceuta' => 'وسطی یورپ کا وقت (سیوٹا)',
        'Africa/Conakry' => 'گرین وچ مین ٹائم (کونکری)',
        'Africa/Dakar' => 'گرین وچ مین ٹائم (ڈکار)',
        'Africa/Freetown' => 'گرین وچ مین ٹائم (فری ٹاؤن)',
        'Africa/Lome' => 'گرین وچ مین ٹائم (لوم)',
        'Africa/Monrovia' => 'گرین وچ مین ٹائم (مونروویا)',
        'Africa/Nouakchott' => 'گرین وچ مین ٹائم (نواکشوط)',
        'Africa/Ouagadougou' => 'گرین وچ مین ٹائم (اؤگاڈؤگوو)',
        'Africa/Sao_Tome' => 'گرین وچ مین ٹائم (ساؤ ٹوم)',
        'Africa/Tunis' => 'وسطی یورپ کا وقت (تیونس)',
        'America/Asuncion' => 'پیراگوئے ٹائم (اسنسیئن)',
        'America/Boa_Vista' => 'ایمیزون ٹائم (بوآ وسٹا)',
        'America/Cambridge_Bay' => 'ماؤنٹین ٹائم (کیمبرج بے)',
        'America/Campo_Grande' => 'ایمیزون ٹائم (کیمپو گرینڈ)',
        'America/Caracas' => 'وینزوئیلا ٹائم (کراکاس)',
        'America/Cayenne' => 'فرینچ گیانا ٹائم (کائین)',
        'America/Cuiaba' => 'ایمیزون ٹائم (کوئیابا)',
        'America/Danmarkshavn' => 'گرین وچ مین ٹائم (ڈنمارک شاون)',
        'America/Glace_Bay' => 'اٹلانٹک ٹائم (گلیس بے)',
        'America/Goose_Bay' => 'اٹلانٹک ٹائم (گوس بے)',
        'America/Grand_Turk' => 'ایسٹرن ٹائم (گرینڈ ترک)',
        'America/Guayaquil' => 'ایکواڈور ٹائم (گوآیاکوئل)',
        'America/Guyana' => 'گیانا ٹائم',
        'America/La_Paz' => 'بولیویا ٹائم (لا پاز)',
        'America/Lima' => 'پیرو ٹائم (لیما)',
        'America/Manaus' => 'ایمیزون ٹائم (مناؤس)',
        'America/Montevideo' => 'یوروگوئے ٹائم (مونٹی ویڈیو)',
        'America/Noronha' => 'فرنانڈو ڈی نورنہا ٹائم (نورونہا)',
        'America/Paramaribo' => 'سورینام ٹائم (پراماریبو)',
        'America/Porto_Velho' => 'ایمیزون ٹائم (پورٹو ویلہو)',
        'America/Punta_Arenas' => 'چلی ٹائم (پنٹا اریناس)',
        'America/Santiago' => 'چلی ٹائم (سنٹیاگو)',
        'America/Scoresbysund' => 'گرین لینڈ وقت (اتتوققورتورمیت)',
        'America/Thule' => 'اٹلانٹک ٹائم (تھولے)',
        'Antarctica/McMurdo' => 'نیوزی لینڈ ٹائم (میک مرڈو)',
        'Antarctica/Palmer' => 'چلی ٹائم (پلمیر)',
        'Antarctica/Rothera' => 'روتھیرا ٹائم',
        'Antarctica/Troll' => 'گرین وچ مین ٹائم (ٹرول)',
        'Antarctica/Vostok' => 'ووسٹاک ٹائم (ووستوک)',
        'Arctic/Longyearbyen' => 'وسطی یورپ کا وقت (لانگ ایئر بین)',
        'Asia/Aden' => 'عرب ٹائم (عدن)',
        'Asia/Ashgabat' => 'ترکمانستان ٹائم (اشغبت)',
        'Asia/Baghdad' => 'عرب ٹائم (بغداد)',
        'Asia/Bahrain' => 'عرب ٹائم (بحرین)',
        'Asia/Baku' => 'آذربائیجان ٹائم (باکو)',
        'Asia/Bishkek' => 'کرغستان ٹائم (بشکیک)',
        'Asia/Calcutta' => 'انڈیا سٹینڈرڈ ٹائم (کولکاتا)',
        'Asia/Kolkata' => 'انڈیا سٹینڈرڈ ٹائم (کولکاتا)',
        'Asia/Colombo' => 'انڈیا سٹینڈرڈ ٹائم (کولمبو)',
        'Asia/Dhaka' => 'بنگلہ دیش ٹائم (ڈھاکہ)',
        'Asia/Dubai' => 'خلیج سٹینڈرڈ ٹائم (دبئی)',
        'Asia/Dushanbe' => 'تاجکستان ٹائم (دوشانبے)',
        'Asia/Jerusalem' => 'اسرائیل ٹائم (یروشلم)',
        'Asia/Kabul' => 'افغانستان ٹائم (کابل)',
        'Asia/Karachi' => 'پاکستان ٹائم (کراچی)',
        'Asia/Katmandu' => 'نیپال ٹائم (کاٹھمنڈو)',
        'Asia/Kathmandu' => 'نیپال ٹائم (کاٹھمنڈو)',
        'Asia/Kuwait' => 'عرب ٹائم (کویت)',
        'Asia/Muscat' => 'خلیج سٹینڈرڈ ٹائم (مسقط)',
        'Asia/Qatar' => 'عرب ٹائم (قطر)',
        'Asia/Riyadh' => 'عرب ٹائم (ریاض)',
        'Asia/Samarkand' => 'ازبکستان ٹائم (سمرقند)',
        'Asia/Tashkent' => 'ازبکستان ٹائم (تاشقند)',
        'Asia/Tbilisi' => 'جارجیا ٹائم (طبلیسی)',
        'Asia/Tehran' => 'ایران ٹائم (تہران)',
        'Asia/Thimphu' => 'بھوٹان ٹائم (تھمپو)',
        'Asia/Yerevan' => 'آرمینیا ٹائم (یریوان)',
        'Atlantic/Reykjavik' => 'گرین وچ مین ٹائم (ریکجاوک)',
        'Atlantic/St_Helena' => 'گرین وچ مین ٹائم (سینٹ ہیلینا)',
        'Atlantic/Stanley' => 'فاک لینڈ آئلینڈز ٹائم (اسٹینلے)',
        'Etc/GMT' => 'گرین وچ مین ٹائم',
        'Europe/Amsterdam' => 'وسطی یورپ کا وقت (ایمسٹرڈم)',
        'Europe/Andorra' => 'وسطی یورپ کا وقت (انڈورا)',
        'Europe/Belgrade' => 'وسطی یورپ کا وقت (بلغراد)',
        'Europe/Berlin' => 'وسطی یورپ کا وقت (برلن)',
        'Europe/Bratislava' => 'وسطی یورپ کا وقت (بریٹِسلاوا)',
        'Europe/Brussels' => 'وسطی یورپ کا وقت (برسلز)',
        'Europe/Budapest' => 'وسطی یورپ کا وقت (بوڈاپیسٹ)',
        'Europe/Busingen' => 'وسطی یورپ کا وقت (بزنجن)',
        'Europe/Copenhagen' => 'وسطی یورپ کا وقت (کوپن ہیگن)',
        'Europe/Dublin' => 'گرین وچ مین ٹائم (ڈبلن)',
        'Europe/Gibraltar' => 'وسطی یورپ کا وقت (جبل الطارق)',
        'Europe/Guernsey' => 'گرین وچ مین ٹائم (گرنزی)',
        'Europe/Isle_of_Man' => 'گرین وچ مین ٹائم (آئل آف مین)',
        'Europe/Jersey' => 'گرین وچ مین ٹائم (جرسی)',
        'Europe/Ljubljana' => 'وسطی یورپ کا وقت (لیوبلیانا)',
        'Europe/London' => 'گرین وچ مین ٹائم (لندن)',
        'Europe/Luxembourg' => 'وسطی یورپ کا وقت (لگژمبرگ)',
        'Europe/Madrid' => 'وسطی یورپ کا وقت (میڈرڈ)',
        'Europe/Malta' => 'وسطی یورپ کا وقت (مالٹا)',
        'Europe/Monaco' => 'وسطی یورپ کا وقت (موناکو)',
        'Europe/Oslo' => 'وسطی یورپ کا وقت (اوسلو)',
        'Europe/Paris' => 'وسطی یورپ کا وقت (پیرس)',
        'Europe/Podgorica' => 'وسطی یورپ کا وقت (پوڈگورسیا)',
        'Europe/Prague' => 'وسطی یورپ کا وقت (پراگ)',
        'Europe/Rome' => 'وسطی یورپ کا وقت (روم)',
        'Europe/San_Marino' => 'وسطی یورپ کا وقت (سان ماریانو)',
        'Europe/Sarajevo' => 'وسطی یورپ کا وقت (سراجیوو)',
        'Europe/Skopje' => 'وسطی یورپ کا وقت (اسکوپجے)',
        'Europe/Stockholm' => 'وسطی یورپ کا وقت (اسٹاک ہوم)',
        'Europe/Tirane' => 'وسطی یورپ کا وقت (ٹیرانی)',
        'Europe/Vaduz' => 'وسطی یورپ کا وقت (ویڈوز)',
        'Europe/Vatican' => 'وسطی یورپ کا وقت (واٹیکن)',
        'Europe/Vienna' => 'وسطی یورپ کا وقت (ویانا)',
        'Europe/Warsaw' => 'وسطی یورپ کا وقت (وارسا)',
        'Europe/Zagreb' => 'وسطی یورپ کا وقت (زیگریب)',
        'Europe/Zurich' => 'وسطی یورپ کا وقت (زیورخ)',
        'Indian/Maldives' => 'مالدیپ ٹائم',
        'Pacific/Auckland' => 'نیوزی لینڈ ٹائم (آکلینڈ)',
        'Pacific/Easter' => 'ایسٹر آئلینڈ ٹائم',
        'Pacific/Galapagos' => 'گالاپاگوز ٹائم (گیلاپیگوس)',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT%s',
    ],
];
